@@ -15,9 +15,16 @@ use crate::constants::*;
 use crate::protocol::{send_lines, write_lines};
 use crate::types::{
     CapitalLettersRecognitionMode, ClientScope, Event, KeyName, MessageId, MessageScope,
-    NotificationType, Priority, PunctuationMode, ReturnCode, Source, StatusLine, SynthesisVoice,
+    NotificationType, Priority, PunctuationMode, ReturnCode, StatusLine, SynthesisVoice,
 };
 
+// Trick to have common implementation for std and mio streams..
+#[cfg(not(feature = "async-mio"))]
+use std::fmt::Debug as Source;
+
+#[cfg(feature = "async-mio")]
+use mio::event::Source;
+
 /// Client error, either I/O error or SSIP error.
 #[derive(ThisError, Debug)]
 pub enum ClientError {
@@ -56,7 +63,7 @@ pub type ClientResult<T> = Result<T, ClientError>;
 pub type ClientStatus = ClientResult<StatusLine>;
 
 /// Client name
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct ClientName {
     pub user: String,
     pub application: String,
@@ -410,6 +417,8 @@ impl<S: Read + Write + Source> Client<S> {
         "SET {} VOLUME {}"
     );
 
+    client_send!(get_volume, "Get the current volume.", "GET VOLUME");
+
     client_send!(
         set_pause_context,
         "Set the number of (more or less) sentences that should be repeated after a previously paused text is resumed.",
@@ -426,8 +435,6 @@ impl<S: Read + Write + Source> Client<S> {
         "SET {} HISTORY {}"
     );
 
-    client_send!(get_volume, "Get the current volume.", "GET VOLUME");
-
     client_send!(block_begin, "Open a block", "BLOCK BEGIN");
 
     client_send!(block_end, "End a block", "BLOCK END");
